<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ar">
<context>
    <name>ChainsProxyPage</name>
    <message>
        <source>Application Proxy</source>
        <translation>تطبيقات البروكسي</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>نوع الوكيل</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>عنوان IP</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>مطلوب</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>المنفذ</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>اسم المستخدم</translation>
    </message>
    <message>
        <source>Optional</source>
        <translation>اختياري</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>كلمة المرور</translation>
    </message>
    <message>
        <source>Check &quot;Use a proxy&quot; in application context menu in Launcher after configured</source>
        <translation>تحقق من &quot;فتح بواسطة بروكسي&quot; من قائمة سياق التطبيق في المشغل لاستخدامها بعد الإعداد</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>إلغاء</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation>حفظ</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>عنوان IP غير صحيح</translation>
    </message>
    <message>
        <source>Invalid port</source>
        <translation>منفذ غير صحيح</translation>
    </message>
</context>
<context>
    <name>ConnectionEditPage</name>
    <message>
        <source>Disconnect</source>
        <comment>button</comment>
        <translation>قطع الاتصال</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>حذف</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>إلغاء</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation>حفظ</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>يتصل</translation>
    </message>
    <message>
        <source>Disconnect</source>
        <translation>قطع الاتصال</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this configuration?</source>
        <translation>أمتأكد من حذفتك لهذا الإعداد؟</translation>
    </message>
    <message>
        <source>Wired Connection %1</source>
        <translation>اتصال سلكي %1</translation>
    </message>
    <message>
        <source>Hotspot</source>
        <translation>نقطة الإتصال</translation>
    </message>
    <message>
        <source>PPPoE Connection %1</source>
        <translation>اتصال PPPoE %1</translation>
    </message>
</context>
<context>
    <name>ConnectionVpnEditPage</name>
    <message>
        <source>New VPN</source>
        <translation>VPN جديد</translation>
    </message>
    <message>
        <source>VPN Type</source>
        <translation>نوع الشبكة الخاصة VPN</translation>
    </message>
    <message>
        <source>L2TP</source>
        <translation>L2TP</translation>
    </message>
    <message>
        <source>PPTP</source>
        <translation>PPTP</translation>
    </message>
    <message>
        <source>OpenVPN</source>
        <translation>OpenVPN </translation>
    </message>
    <message>
        <source>OpenConnect</source>
        <translation>OpenConnect</translation>
    </message>
    <message>
        <source>StrongSwan</source>
        <translation>StrongSwan</translation>
    </message>
    <message>
        <source>VPNC</source>
        <translation>VPNC</translation>
    </message>
    <message>
        <source>Export</source>
        <comment>button</comment>
        <translation>تصدير</translation>
    </message>
    <message>
        <source>VPN L2TP %1</source>
        <translation>VPN L2TP %1</translation>
    </message>
    <message>
        <source>VPN PPTP %1</source>
        <translation>VPN PPTP %1</translation>
    </message>
    <message>
        <source>VPN VPNC %1</source>
        <translation>VPN VPNC %1</translation>
    </message>
    <message>
        <source>VPN OpenVPN %1</source>
        <translation>VPN OpenVPN %1</translation>
    </message>
    <message>
        <source>VPN StrongSwan %1</source>
        <translation>VPN StrongSwan %1</translation>
    </message>
    <message>
        <source>VPN OpenConnect %1</source>
        <translation>VPN OpenConnect %1</translation>
    </message>
</context>
<context>
    <name>DCCNetworkModule</name>
    <message>
        <source>Network</source>
        <translation>الشبكة</translation>
    </message>
    <message>
        <source>Application Proxy</source>
        <translation>تطبيقات البروكسي</translation>
    </message>
    <message>
        <source>Personal Hotspot</source>
        <translation>Hotspot شخصية</translation>
    </message>
    <message>
        <source>Network Details</source>
        <translation>تفاصيل الشبكة</translation>
    </message>
    <message>
        <source>System Proxy</source>
        <translation>وكيل النظام</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>شبكة سلكية</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>شبكة لاسلكية</translation>
    </message>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Airplane Mode</source>
        <translation type="unfinished"/>
        <extra-child_page>Airplane Mode</extra-child_page>
        <extra-contents_path>/network/Airplane Mode</extra-contents_path>
    </message>
    <message>
        <source>Wired Network Adapter</source>
        <translation>محول شبكة سلكية</translation>
        <extra-child_page>Wired Network</extra-child_page>
        <extra-contents_path>/network/Wired Network</extra-contents_path>
    </message>
    <message>
        <source>Add Network Connection</source>
        <translation>إضافة اتصال شبكة</translation>
        <extra-child_page>Wired Network</extra-child_page>
        <extra-contents_path>/network/Wired Network/addWiredConnection</extra-contents_path>
    </message>
    <message>
        <source>Wireless Network Adapter</source>
        <translation>كرت الشبكة اللاسلكية</translation>
        <extra-child_page>Wireless Network</extra-child_page>
        <extra-contents_path>/network/Wireless Network</extra-contents_path>
    </message>
    <message>
        <source>Connect to hidden network</source>
        <translation>الإتصال بشبكة مخفية</translation>
        <extra-child_page>Wireless Network</extra-child_page>
        <extra-contents_path>/network/Wireless Network/Connect to hidden network</extra-contents_path>
    </message>
    <message>
        <source>DSL</source>
        <translation>DSL</translation>
        <extra-child_page_hide>DSL</extra-child_page_hide>
        <extra-contents_path>/network/DSL</extra-contents_path>
    </message>
    <message>
        <source>Create PPPoE Connection</source>
        <translation>إنشاء اتصال PPPoE</translation>
        <extra-child_page>DSL</extra-child_page>
        <extra-contents_path>/network/DSL/Create PPPoE Connection</extra-contents_path>
    </message>
    <message>
        <source>VPN Status</source>
        <translation>حالة VPN</translation>
        <extra-child_page>VPN</extra-child_page>
        <extra-contents_path>/network/VPN</extra-contents_path>
    </message>
    <message>
        <source>Create VPN</source>
        <translation>إنشاء VPN</translation>
        <extra-child_page>VPN</extra-child_page>
        <extra-contents_path>/network/VPN/Create VPN</extra-contents_path>
    </message>
    <message>
        <source>Import VPN</source>
        <translation>إستيراد شبكة خاصة إفتراضية</translation>
        <extra-child_page>VPN</extra-child_page>
        <extra-contents_path>/network/VPN/Import VPN</extra-contents_path>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>نوع الوكيل</translation>
        <extra-child_page>Application Proxy</extra-child_page>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
    </message>
    <message>
        <source>Configuration URL</source>
        <translation>إعداد الرابط</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>عنوان IP</translation>
        <extra-child_page>Application Proxy</extra-child_page>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
    </message>
    <message>
        <source>Port</source>
        <translation>المنفذ</translation>
        <extra-child_page>Application Proxy</extra-child_page>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
    </message>
    <message>
        <source>Username</source>
        <translation>اسم المستخدم</translation>
        <extra-child_page>Application Proxy</extra-child_page>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
    </message>
    <message>
        <source>Password</source>
        <translation>كلمة المرور</translation>
        <extra-child_page>Application Proxy</extra-child_page>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
    </message>
    <message>
        <source>Hotspot</source>
        <translation>نقطة الإتصال</translation>
        <extra-child_page>Personal Hotspot</extra-child_page>
        <extra-contents_path>/network/Personal Hotspot</extra-contents_path>
    </message>
    <message>
        <source>Create Hotspot</source>
        <translation>إنشاء Hotspot</translation>
        <extra-child_page>Personal Hotspot</extra-child_page>
        <extra-contents_path>/network/Personal Hotspot/Create Hotspot</extra-contents_path>
    </message>
    <message>
        <source>Interface</source>
        <translation>الواجهة</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>MAC</source>
        <translation>ماك</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Band</source>
        <translation>الحزمة</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Gateway</source>
        <translation>البوابة</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>DNS رئيسي</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Netmask</source>
        <translation>قناع الشبكة</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Prefix</source>
        <translation>البادئة</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Speed</source>
        <translation>السرعة</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
</context>
<context>
    <name>dccV20::network::AirplaneModepage</name>
    <message>
        <source>Airplane Mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Enabling the airplane mode turns off wireless network, personal hotspot and Bluetooth</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>DNSSection</name>
    <message>
        <source>DNS</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid DNS address</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>EthernetSection</name>
    <message>
        <source>Ethernet</source>
        <translation>إيثرنت</translation>
    </message>
    <message>
        <source>Not Bind</source>
        <translation>لا يوجد جهاز مرتبط بعنوان ال MAC</translation>
    </message>
    <message>
        <source>Device MAC Addr</source>
        <translation>عنوان MAC الجهاز </translation>
    </message>
    <message>
        <source>Cloned MAC Addr</source>
        <translation>عنوان MAC المستنسخ </translation>
    </message>
    <message>
        <source>Customize MTU</source>
        <translation>تخصيص MTU</translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>MTU</translation>
    </message>
</context>
<context>
    <name>GenericHotspotSection</name>
    <message>
        <source>General</source>
        <translation>عام</translation>
    </message>
    <message>
        <source>Name (SSID)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Required</source>
        <translation>مطلوب</translation>
    </message>
</context>
<context>
    <name>GenericSection</name>
    <message>
        <source>General</source>
        <translation>عام</translation>
    </message>
    <message>
        <source>The name already exists</source>
        <translation>الاسم موجود بالفعل</translation>
    </message>
    <message>
        <source>Name (SSID)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Name</source>
        <translation>الاسم</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>مطلوب</translation>
    </message>
    <message>
        <source>Auto Connect</source>
        <translation>اتصال تلقائي</translation>
    </message>
</context>
<context>
    <name>HotspotDeviceWidget</name>
    <message>
        <source>Hotspot</source>
        <translation>نقطة الإتصال</translation>
    </message>
    <message>
        <source>Add Settings</source>
        <translation>إضافة إعدادات</translation>
    </message>
</context>
<context>
    <name>HotspotPage</name>
    <message>
        <source>Create Hotspot</source>
        <translation>إنشاء Hotspot</translation>
    </message>
</context>
<context>
    <name>IPInputSection</name>
    <message>
        <source>IP Address</source>
        <translation>عنوان IP</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>مطلوب</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>البوابة</translation>
    </message>
</context>
<context>
    <name>IPV4InputSection</name>
    <message>
        <source>Duplicate IP address</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>عنوان IP غير صحيح</translation>
    </message>
    <message>
        <source>Invalid netmask</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Only one gateway is allowed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>بوابة غير صالحة</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>قناع الشبكة</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>مطلوب</translation>
    </message>
</context>
<context>
    <name>IPV6InputSection</name>
    <message>
        <source>Duplicate IP address</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>عنوان IP غير صحيح</translation>
    </message>
    <message>
        <source>Only one gateway is allowed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>بوابة غير صالحة</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>البادئة</translation>
    </message>
</context>
<context>
    <name>IpvxSection</name>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>تلقائي</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>يدوي</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>تجاهل</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>عنوان IP</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>مطلوب</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>البوابة</translation>
    </message>
    <message>
        <source>Only applied in corresponding resources</source>
        <translation>يطبق فقط في الموارد المتطابقة</translation>
    </message>
    <message>
        <source>Method</source>
        <translation>اﻷسلوب</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>قناع الشبكة</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>البادئة</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>عنوان IP غير صحيح</translation>
    </message>
    <message>
        <source>Invalid netmask</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>بوابة غير صالحة</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>الشبكة</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MultiIpvxSection</name>
    <message>
        <source>Method</source>
        <translation>اﻷسلوب</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>تلقائي</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>يدوي</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>تجاهل</translation>
    </message>
</context>
<context>
    <name>NetworkDetailPage</name>
    <message>
        <source>Network Details</source>
        <translation>تفاصيل الشبكة</translation>
    </message>
</context>
<context>
    <name>NetworkModuleWidget</name>
    <message>
        <source>DSL</source>
        <translation>DSL</translation>
    </message>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>System Proxy</source>
        <translation>وكيل النظام</translation>
    </message>
    <message>
        <source>Application Proxy</source>
        <translation>تطبيقات البروكسي</translation>
    </message>
    <message>
        <source>Airplane Mode</source>
        <translation type="unfinished"/>
        <extra-contents_path>/network/Airplane</extra-contents_path>
    </message>
    <message>
        <source>Network Details</source>
        <translation>تفاصيل الشبكة</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>الشبكة</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Disabled</source>
        <translation>معطل</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>يدوي</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>تلقائي</translation>
    </message>
    <message>
        <source>Configure by Network Manager</source>
        <translation>إعداد بواسطة مدير الشبكة</translation>
    </message>
    <message>
        <source>Personal Hotspot</source>
        <translation>Hotspot شخصية</translation>
    </message>
</context>
<context>
    <name>PPPOESection</name>
    <message>
        <source>PPPoE</source>
        <translation>PPPoE</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>اسم المستخدم</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>مطلوب</translation>
    </message>
    <message>
        <source>Service</source>
        <translation>خدمة</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>كلمة المرور</translation>
    </message>
</context>
<context>
    <name>PPPSection</name>
    <message>
        <source>PPP</source>
        <translation>PPP</translation>
    </message>
    <message>
        <source>Refuse EAP Authentication</source>
        <translation>رفض مصادقة الـ EAP</translation>
    </message>
    <message>
        <source>Refuse PAP Authentication</source>
        <translation>رفض مصادقة الـ PAP</translation>
    </message>
    <message>
        <source>Refuse CHAP Authentication</source>
        <translation>رفض مصادقة الـ CHAP</translation>
    </message>
    <message>
        <source>Refuse MSCHAP Authentication</source>
        <translation>رفض مصادقة الـ MSCHAP</translation>
    </message>
    <message>
        <source>Refuse MSCHAPv2 Authentication</source>
        <translation>رفض مصادقة الـ MSCHAPv2</translation>
    </message>
    <message>
        <source>No BSD Data Compression</source>
        <translation>عدم ضغط بيانات  BSD</translation>
    </message>
    <message>
        <source>No Deflate Data Compression</source>
        <translation>عدم ضغط البيانات الضئيلة</translation>
    </message>
    <message>
        <source>No TCP Header Compression</source>
        <translation>عدم ضغط بيانات  TCP الرأسية</translation>
    </message>
    <message>
        <source>No Protocol Field Compression</source>
        <translation>عدم ضغط حقل البروتوكول</translation>
    </message>
    <message>
        <source>No Address/Control Compression</source>
        <translation>لا يوجد  ضغط عنوا ن\تحكم     </translation>
    </message>
    <message>
        <source>Send PPP Echo Packets</source>
        <translation>إرسال حزم صدى PPP  </translation>
    </message>
    <message>
        <source>Use MPPE</source>
        <translation>استخدام MPPE  </translation>
    </message>
    <message>
        <source>128-bit MPPE</source>
        <translation>128-bit MPPE</translation>
    </message>
    <message>
        <source>Stateful MPPE</source>
        <translation>Stateful MPPE</translation>
    </message>
</context>
<context>
    <name>PppoePage</name>
    <message>
        <source>Create PPPoE Connection</source>
        <translation>إنشاء اتصال PPPoE</translation>
    </message>
    <message>
        <source>PPP</source>
        <translation>PPP</translation>
    </message>
</context>
<context>
    <name>ProxyPage</name>
    <message>
        <source>System Proxy</source>
        <translation>وكيل النظام</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>إلغاء</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation>حفظ</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>نوع الوكيل</translation>
        <extra-child_page>System Proxy</extra-child_page>
        <extra-contents_path>/network/System Proxy</extra-contents_path>
    </message>
    <message>
        <source>Manual</source>
        <translation>يدوي</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>تلقائي</translation>
    </message>
    <message>
        <source>Optional</source>
        <translation>اختياري</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>المنفذ</translation>
    </message>
    <message>
        <source>Authentication is required</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Username</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Required</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Password</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>HTTP Proxy</source>
        <translation>وكيل HTTP </translation>
    </message>
    <message>
        <source>HTTPS Proxy</source>
        <translation>وكيل HTTPS</translation>
    </message>
    <message>
        <source>FTP Proxy</source>
        <translation>وكيل FTP</translation>
    </message>
    <message>
        <source>SOCKS Proxy</source>
        <translation>وكيل Socks</translation>
    </message>
    <message>
        <source>Ignore the proxy configurations for the above hosts and domains</source>
        <translation>تجاهل إعدادات الوكيل من أجل الإستضافات و النطاقات أعلاه</translation>
    </message>
    <message>
        <source>Configuration URL</source>
        <translation>إعداد الرابط</translation>
        <extra-child_page>System Proxy</extra-child_page>
        <extra-contents_path>/network/System Proxy</extra-contents_path>
    </message>
</context>
<context>
    <name>Secret8021xSection</name>
    <message>
        <source>Security</source>
        <translation>الأمان</translation>
    </message>
    <message>
        <source>TLS</source>
        <translation>TLS</translation>
    </message>
    <message>
        <source>MD5</source>
        <translation>MD5 </translation>
    </message>
    <message>
        <source>LEAP</source>
        <translation>LEAP</translation>
    </message>
    <message>
        <source>FAST</source>
        <translation>FAST</translation>
    </message>
    <message>
        <source>Tunneled TLS</source>
        <translation>نفق TLS</translation>
    </message>
    <message>
        <source>Protected EAP</source>
        <translation>EAP محمي</translation>
    </message>
    <message>
        <source>Save password for this user</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Save password for all users</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Ask me always</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Disabled</source>
        <translation>معطل</translation>
    </message>
    <message>
        <source>Anonymous</source>
        <translation>مجهول</translation>
    </message>
    <message>
        <source>Authenticated</source>
        <translation>موثوق</translation>
    </message>
    <message>
        <source>Both</source>
        <translation>المسار</translation>
    </message>
    <message>
        <source>Automatic</source>
        <translation>تلقائي</translation>
    </message>
    <message>
        <source>Version 0</source>
        <translation>الاصدار 0</translation>
    </message>
    <message>
        <source>Version 1</source>
        <translation>الاصدار 1</translation>
    </message>
    <message>
        <source>EAP Auth</source>
        <translation>مصادقة EAP</translation>
    </message>
    <message>
        <source>Identity</source>
        <translation>الهوية</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>مطلوب</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>خيارات Pwd</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>مفتاح خاص</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>شهادة CA</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>رخصة المستخدم</translation>
    </message>
    <message>
        <source>Anonymous ID</source>
        <translation>هوية مجهولة</translation>
    </message>
    <message>
        <source>Provisioning</source>
        <translation>تجهيز</translation>
    </message>
    <message>
        <source>PAC file</source>
        <translation>ملف إعداد الوكيل PAC</translation>
    </message>
    <message>
        <source>Inner Auth</source>
        <translation>مصادقة داخلية</translation>
    </message>
    <message>
        <source>PEAP Version</source>
        <translation>إصدار PEAP</translation>
    </message>
    <message>
        <source>Private Pwd</source>
        <translation>خاص Pwd</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>كلمة المرور</translation>
    </message>
</context>
<context>
    <name>SecretHotspotSection</name>
    <message>
        <source>Invalid password</source>
        <translation>كلمة المرور غير صحيحة</translation>
    </message>
    <message>
        <source>None</source>
        <translation>لا شيء</translation>
    </message>
    <message>
        <source>WEP</source>
        <translation>WEP</translation>
    </message>
    <message>
        <source>WPA/WPA2 Personal</source>
        <translation>WPA/WPA2 Personal</translation>
    </message>
    <message>
        <source>WPA3 Personal</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Security</source>
        <translation>الأمان</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>مطلوب</translation>
    </message>
    <message>
        <source>Key</source>
        <translation>المفتاح</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>كلمة المرور</translation>
    </message>
</context>
<context>
    <name>SecretWiredSection</name>
    <message>
        <source>Security Required</source>
        <translation>الحماية مطلوبة</translation>
    </message>
</context>
<context>
    <name>SecretWirelessSection</name>
    <message>
        <source>Invalid password</source>
        <translation>كلمة المرور غير صحيحة</translation>
    </message>
    <message>
        <source>None</source>
        <translation>لا شيء</translation>
    </message>
    <message>
        <source>WEP</source>
        <translation>WEP</translation>
    </message>
    <message>
        <source>WPA/WPA2 Personal</source>
        <translation>WPA/WPA2 Personal</translation>
    </message>
    <message>
        <source>WPA/WPA2 Enterprise</source>
        <translation>WPA/WPA2 Enterprise</translation>
    </message>
    <message>
        <source>WPA3 Personal</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Shared key</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Open system</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Security</source>
        <translation>الأمان</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>مطلوب</translation>
    </message>
    <message>
        <source>Authentication</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Key</source>
        <translation>المفتاح</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>كلمة المرور</translation>
    </message>
</context>
<context>
    <name>VpnAdvOpenVPNSection</name>
    <message>
        <source>VPN Advanced</source>
        <translation>VPN متقدم </translation>
    </message>
    <message>
        <source>Customize Gateway Port</source>
        <translation>تخصيص منفذ البوابة</translation>
    </message>
    <message>
        <source>Gateway Port</source>
        <translation>منفذ البوابة</translation>
    </message>
    <message>
        <source>Customize Renegotiation Interval</source>
        <translation>تخصيص إعادة التفاوض</translation>
    </message>
    <message>
        <source>Renegotiation Interval</source>
        <translation>  فاصل  إعادة تفاوض </translation>
    </message>
    <message>
        <source>Use LZO Data Compression</source>
        <translation>استخدام ضغط بيانات الـ LZO</translation>
    </message>
    <message>
        <source>Use TCP Connection</source>
        <translation>استخدام اتصال TCP</translation>
    </message>
    <message>
        <source>Use TAP Device</source>
        <translation>استخدام جهاز TAP</translation>
    </message>
    <message>
        <source>Customize Tunnel MTU</source>
        <translation>تخصيص نفق MTU </translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>MTU</translation>
    </message>
    <message>
        <source>Customize UDP Fragment Size</source>
        <translation>تخصيص حجم الجزء UDP</translation>
    </message>
    <message>
        <source>UDP Fragment Size</source>
        <translation>حجم جزء UDP </translation>
    </message>
    <message>
        <source>Restrict Tunnel TCP MSS</source>
        <translation>تقييد نفق TCP MSS</translation>
    </message>
    <message>
        <source>Randomize Remote Hosts</source>
        <translation>المضيفون البعيدون عشوائياً</translation>
    </message>
</context>
<context>
    <name>VpnAdvVPNCSection</name>
    <message>
        <source>VPN Advanced</source>
        <translation>VPN متقدم </translation>
    </message>
    <message>
        <source>Cisco (default)</source>
        <translation>سيسكو (افتراضي)</translation>
    </message>
    <message>
        <source>Netscreen</source>
        <translation>Netscreen</translation>
    </message>
    <message>
        <source>Secure (default)</source>
        <translation>محمي (افتراضي)</translation>
    </message>
    <message>
        <source>Weak</source>
        <translation>ضعيف</translation>
    </message>
    <message>
        <source>None</source>
        <translation>لا شيء</translation>
    </message>
    <message>
        <source>NAT-T When Available (default)</source>
        <translation>NAT-T عندما تكون متوفرة (افتراضي)</translation>
    </message>
    <message>
        <source>NAT-T Always</source>
        <translation>NAT-T دائماً</translation>
    </message>
    <message>
        <source>Cisco UDP</source>
        <translation>سيسكو UDP</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>معطل</translation>
    </message>
    <message>
        <source>DH Group 1</source>
        <translation>DH Group 1</translation>
    </message>
    <message>
        <source>DH Group 2 (default)</source>
        <translation>DH مجموعة2 (افتراضي)</translation>
    </message>
    <message>
        <source>DH Group 5</source>
        <translation>DH Group 5</translation>
    </message>
    <message>
        <source>Server (default)</source>
        <translation>الخادم (افتراضي)</translation>
    </message>
    <message>
        <source>DH Group 2</source>
        <translation>DH Group 2</translation>
    </message>
    <message>
        <source>Domain</source>
        <translation>النطاق</translation>
    </message>
    <message>
        <source>Vendor</source>
        <translation>المورّد</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>الإصدار</translation>
    </message>
    <message>
        <source>Encryption</source>
        <translation>التشفير</translation>
    </message>
    <message>
        <source>NAT Traversal Mode</source>
        <translation>وضع اجتيار NAT</translation>
    </message>
    <message>
        <source>IKE DH Group</source>
        <translation>IKE DH مجموعة </translation>
    </message>
    <message>
        <source>Forward Secrecy</source>
        <translation>التقدم المحمي</translation>
    </message>
    <message>
        <source>Local Port</source>
        <translation>منفذ محلي</translation>
    </message>
    <message>
        <source>Disable Dead Peer Detection</source>
        <translation>تعطيل كشف النظير المفقود</translation>
    </message>
</context>
<context>
    <name>VpnIpsecSection</name>
    <message>
        <source>VPN IPsec</source>
        <translation>VPN IPsec</translation>
    </message>
    <message>
        <source>Enable IPsec</source>
        <translation>تمكين IPsec </translation>
    </message>
    <message>
        <source>Group Name</source>
        <translation>اسم المجموعة </translation>
    </message>
    <message>
        <source>Group ID</source>
        <translation>هوية المجموعة</translation>
    </message>
    <message>
        <source>Pre-Shared Key</source>
        <translation>مفتاح مشترك مسبقاً</translation>
    </message>
    <message>
        <source>Phase1 Algorithms</source>
        <translation>خوارزميات المرحلة 1</translation>
    </message>
    <message>
        <source>Phase2 Algorithms</source>
        <translation>خوارزميات المرحلة 2</translation>
    </message>
</context>
<context>
    <name>VpnOpenConnectSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>بوابة غير صالحة</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>البوابة</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>مطلوب</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>شهادة CA</translation>
    </message>
    <message>
        <source>Proxy</source>
        <translation>الوكيل</translation>
    </message>
    <message>
        <source>Allow Cisco Secure Desktop Trojan</source>
        <translation>السماح لـ Cisco Secure Desktop Trojan</translation>
    </message>
    <message>
        <source>CSD Script</source>
        <translation>CSD Script</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>رخصة المستخدم</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>مفتاح خاص</translation>
    </message>
    <message>
        <source>Use FSID for Key Passphrase</source>
        <translation>استخدام &quot;FSID&quot; لمفتاح العبور</translation>
    </message>
</context>
<context>
    <name>VpnOpenVPNSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>بوابة غير صالحة</translation>
    </message>
    <message>
        <source>Certificates (TLS)</source>
        <translation>شهادات (TLS)</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>كلمة المرور</translation>
    </message>
    <message>
        <source>Certificates with Password (TLS)</source>
        <translation>الشهادات مع كلمة سر (TLS)</translation>
    </message>
    <message>
        <source>Static Key</source>
        <translation>مفتاح ثابت</translation>
    </message>
    <message>
        <source>Saved</source>
        <translation>تم الحفظ</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>اسأل</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>غير مطلوب</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>البوابة</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>مطلوب</translation>
    </message>
    <message>
        <source>Auth Type</source>
        <translation>نوع المصادقة</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>شهادة CA</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>رخصة المستخدم</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>مفتاح خاص</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>خيارات Pwd</translation>
    </message>
    <message>
        <source>Private Pwd</source>
        <translation>خاص Pwd</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>اسم المستخدم</translation>
    </message>
    <message>
        <source>Customize Key Direction</source>
        <translation>تخصيص توجيه المفاتيح</translation>
    </message>
    <message>
        <source>Key Direction</source>
        <translation>اتجاه المفتاح</translation>
    </message>
    <message>
        <source>Remote IP</source>
        <translation>IP بعيد</translation>
    </message>
    <message>
        <source>Local IP</source>
        <translation>IP محلي</translation>
    </message>
</context>
<context>
    <name>VpnPPPSection</name>
    <message>
        <source>VPN PPP</source>
        <translation>VPN PPP</translation>
    </message>
    <message>
        <source>All Available (default)</source>
        <translation>كل ماهو متاح  (افتراضي)</translation>
    </message>
    <message>
        <source>40-bit (less secure)</source>
        <translation>40-بت (أقل أمناً)</translation>
    </message>
    <message>
        <source>128-bit (most secure)</source>
        <translation>128-بت (الأكثر أماناً)</translation>
    </message>
    <message>
        <source>Refuse EAP Authentication</source>
        <translation>رفض مصادقة الـ EAP</translation>
    </message>
    <message>
        <source>Refuse PAP Authentication</source>
        <translation>رفض مصادقة الـ PAP</translation>
    </message>
    <message>
        <source>Refuse CHAP Authentication</source>
        <translation>رفض مصادقة الـ CHAP</translation>
    </message>
    <message>
        <source>Refuse MSCHAP Authentication</source>
        <translation>رفض مصادقة الـ MSCHAP</translation>
    </message>
    <message>
        <source>Refuse MSCHAPv2 Authentication</source>
        <translation>رفض مصادقة الـ MSCHAPv2</translation>
    </message>
    <message>
        <source>No BSD Data Compression</source>
        <translation>عدم ضغط بيانات  BSD</translation>
    </message>
    <message>
        <source>No Deflate Data Compression</source>
        <translation>عدم ضغط البيانات الضئيلة</translation>
    </message>
    <message>
        <source>No TCP Header Compression</source>
        <translation>عدم ضغط بيانات  TCP الرأسية</translation>
    </message>
    <message>
        <source>No Protocol Field Compression</source>
        <translation>عدم ضغط حقل البروتوكول</translation>
    </message>
    <message>
        <source>No Address/Control Compression</source>
        <translation>لا يوجد  ضغط عنوا ن\تحكم     </translation>
    </message>
    <message>
        <source>Send PPP Echo Packets</source>
        <translation>إرسال حزم صدى PPP  </translation>
    </message>
    <message>
        <source>Use MPPE</source>
        <translation>استخدام MPPE  </translation>
    </message>
    <message>
        <source>Security</source>
        <translation>الأمان</translation>
    </message>
    <message>
        <source>Stateful MPPE</source>
        <translation>Stateful MPPE</translation>
    </message>
</context>
<context>
    <name>VpnPage</name>
    <message>
        <source>VPN Status</source>
        <translation>حالة VPN</translation>
    </message>
    <message>
        <source>Create VPN</source>
        <translation>إنشاء VPN</translation>
    </message>
    <message>
        <source>Import VPN</source>
        <translation>إستيراد شبكة خاصة إفتراضية</translation>
    </message>
    <message>
        <source>Import Error</source>
        <translation>خطأ في الإستيراد</translation>
    </message>
    <message>
        <source>File error</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>OK</source>
        <translation>موافق</translation>
    </message>
</context>
<context>
    <name>VpnProxySection</name>
    <message>
        <source>VPN Proxy</source>
        <translation>وكلاء شبكة VPN</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>غير مطلوب</translation>
    </message>
    <message>
        <source>HTTP</source>
        <translation>HTTP</translation>
    </message>
    <message>
        <source>SOCKS</source>
        <translation>SOCKS</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>نوع الوكيل</translation>
    </message>
    <message>
        <source>Server IP</source>
        <translation>Server IP</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>مطلوب</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>المنفذ</translation>
    </message>
    <message>
        <source>Retry Indefinitely When Failed</source>
        <translation>إعادة محاولات غير محددة وعند الفشل</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>اسم المستخدم</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>كلمة المرور</translation>
    </message>
</context>
<context>
    <name>VpnSSTPSection</name>
    <message>
        <source>CA File</source>
        <translation>CA ملف </translation>
    </message>
    <message>
        <source>Ignore Certificate Warnings</source>
        <translation>تجاهل تحذيرات الشهادات</translation>
    </message>
    <message>
        <source>Use TLS Hostname Extensions</source>
        <translation>استخدم TLS Hostname Extensions</translation>
    </message>
</context>
<context>
    <name>VpnSecOpenVPNSection</name>
    <message>
        <source>VPN Security</source>
        <translation>حماية vpn</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>افتراضي</translation>
    </message>
    <message>
        <source>None</source>
        <translation>لا شيء</translation>
    </message>
    <message>
        <source>Cipher</source>
        <translation>الشيفرة</translation>
    </message>
    <message>
        <source>HMAC Auth</source>
        <translation>HMAC مصادقة</translation>
    </message>
</context>
<context>
    <name>VpnSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>بوابة غير صالحة</translation>
    </message>
    <message>
        <source>Saved</source>
        <translation>تم الحفظ</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>اسأل</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>غير مطلوب</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>البوابة</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>مطلوب</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>اسم المستخدم</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>خيارات Pwd</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>كلمة المرور</translation>
    </message>
    <message>
        <source>NT Domain</source>
        <translation>NT Domain</translation>
    </message>
</context>
<context>
    <name>VpnSstpProxySection</name>
    <message>
        <source>VPN Proxy</source>
        <translation>وكلاء شبكة VPN</translation>
    </message>
    <message>
        <source>Server IP</source>
        <translation>Server IP</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>المنفذ</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>اسم المستخدم</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>كلمة المرور</translation>
    </message>
</context>
<context>
    <name>VpnStrongSwanSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>بوابة غير صالحة</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>مفتاح خاص</translation>
    </message>
    <message>
        <source>SSH Agent</source>
        <translation>وكيل SSH</translation>
    </message>
    <message>
        <source>Smart Card</source>
        <translation>بطاقة ذكية</translation>
    </message>
    <message>
        <source>EAP</source>
        <translation>EAP</translation>
    </message>
    <message>
        <source>Pre-Shared Key</source>
        <translation>مفتاح مشترك مسبقاً</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>البوابة</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>مطلوب</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>شهادة CA</translation>
    </message>
    <message>
        <source>Auth Type</source>
        <translation>نوع المصادقة</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>رخصة المستخدم</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>اسم المستخدم</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>كلمة المرور</translation>
    </message>
    <message>
        <source>Request an Inner IP Address</source>
        <translation>مطلوب عنوان IP داخلي</translation>
    </message>
    <message>
        <source>Enforce UDP Encapsulation</source>
        <translation>فرض تغليف UDP</translation>
    </message>
    <message>
        <source>Use IP Compression</source>
        <translation>استخدام ضغط عناوين  IP </translation>
    </message>
    <message>
        <source>Enable Custom Cipher Proposals</source>
        <translation>تشغيل Custom Cipher Proposals</translation>
    </message>
    <message>
        <source>IKE</source>
        <translation>IKE</translation>
    </message>
    <message>
        <source>ESP</source>
        <translation>ESP</translation>
    </message>
</context>
<context>
    <name>VpnTLSSection</name>
    <message>
        <source>VPN TLS Authentication</source>
        <translation> مصادقة VPN  TLS</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>افتراضي</translation>
    </message>
    <message>
        <source>Client</source>
        <translation>عميل</translation>
    </message>
    <message>
        <source>Server</source>
        <translation>الخادم</translation>
    </message>
    <message>
        <source>Subject Match</source>
        <translation>مطابقة الموضوع</translation>
    </message>
    <message>
        <source>Remote Cert Type</source>
        <translation>نوع الشهادة البعيدة</translation>
    </message>
    <message>
        <source>Key File</source>
        <translation>مفتاح الملف</translation>
    </message>
    <message>
        <source>Customize Key Direction</source>
        <translation>تخصيص توجيه المفاتيح</translation>
    </message>
    <message>
        <source>Key Direction</source>
        <translation>اتجاه المفتاح</translation>
    </message>
</context>
<context>
    <name>VpnVPNCSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>بوابة غير صالحة</translation>
    </message>
    <message>
        <source>Saved</source>
        <translation>تم الحفظ</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>اسأل</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>غير مطلوب</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>البوابة</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>مطلوب</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>اسم المستخدم</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>خيارات Pwd</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>كلمة المرور</translation>
    </message>
    <message>
        <source>Group Name</source>
        <translation>اسم المجموعة </translation>
    </message>
    <message>
        <source>Group Pwd</source>
        <translation>مجموعة Pwd</translation>
    </message>
    <message>
        <source>Use Hybrid Authentication</source>
        <translation>استخدام المصادقة الهجينة</translation>
    </message>
    <message>
        <source>CA File</source>
        <translation>CA ملف </translation>
    </message>
</context>
<context>
    <name>WiredPage</name>
    <message>
        <source>Plug in the network cable first</source>
        <translation>قم بتوصيل سلك الشبكة أولًا</translation>
    </message>
    <message>
        <source>Wired Network Adapter</source>
        <translation>محول شبكة سلكية</translation>
    </message>
    <message>
        <source>Add Network Connection</source>
        <translation>إضافة اتصال شبكة</translation>
    </message>
    <message>
        <source>Select Settings</source>
        <translation>تحديد الإعدادات</translation>
    </message>
</context>
<context>
    <name>WirelessPage</name>
    <message>
        <source>Wireless Network Adapter</source>
        <translation>كرت الشبكة اللاسلكية</translation>
        <extra-contents_path>/network/Wireless Network</extra-contents_path>
    </message>
    <message>
        <source>Close Hotspot</source>
        <translation>أغلق نقطة الاتصال</translation>
    </message>
    <message>
        <source>Disable hotspot first if you want to connect to a wireless network</source>
        <translation>يرجى أولا تعطيل مشاركة &quot;نقطة الاتصال&quot; إذا كنت ترغب في الاتصال واستخدام وظيفة الشبكة اللاسلكية</translation>
    </message>
    <message>
        <source>Connect to hidden network</source>
        <translation>الإتصال بشبكة مخفية</translation>
        <extra-child_page>WirelessPage</extra-child_page>
        <extra-contents_path>/network/Connect to hidden network</extra-contents_path>
    </message>
</context>
<context>
    <name>WirelessSection</name>
    <message>
        <source>WLAN</source>
        <translation>الشبكة المحلية اللاسلكية</translation>
    </message>
    <message>
        <source>Not Bind</source>
        <translation>لا يوجد جهاز مرتبط بعنوان ال MAC</translation>
    </message>
    <message>
        <source>Device MAC Addr</source>
        <translation>عنوان MAC الجهاز </translation>
    </message>
    <message>
        <source>Customize MTU</source>
        <translation>تخصيص MTU</translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>MTU</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDetails</name>
    <message>
        <source>Hotspot</source>
        <translation>نقطة الإتصال</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID </translation>
    </message>
    <message>
        <source>Protocol</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Security Type</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Channel</source>
        <translation>القناة</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>الحزمة</translation>
    </message>
    <message>
        <source>Interface</source>
        <translation>الواجهة</translation>
    </message>
    <message>
        <source>MAC</source>
        <translation>ماك</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>قناع الشبكة</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>البوابة</translation>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>DNS رئيسي</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>البادئة</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>السرعة</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDeviceRealize</name>
    <message>
        <source>Device disabled</source>
        <translation>جهاز ملغى</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>متصل لكن لا يوجد اتصال بالإنترنت</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>غير متصل</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>سلك الشبكة غير موصول</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>يتصل</translation>
    </message>
    <message>
        <source>Authenticating</source>
        <translation>المصادقة</translation>
    </message>
    <message>
        <source>Obtaining IP address</source>
        <translation>جاري الحصول على عنوان IP</translation>
    </message>
    <message>
        <source>Connected</source>
        <translation>متصل</translation>
    </message>
    <message>
        <source>Disconnected</source>
        <translation>غير متصل</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed</source>
        <translation>فشل</translation>
    </message>
    <message>
        <source>Obtaining address</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>dde::network::NetworkProcesser</name>
    <message>
        <source>Wired Network</source>
        <translation>شبكة سلكية</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>شبكة سلكية 1%</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>شبكة لاسلكية</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>الشبكة اللاسلكية : %1</translation>
    </message>
</context>
</TS>